#include <errno.h>
#include <stdio.h>
#include <stdarg.h>
#include <string.h>

#define NO_STDERR_OUTP

#define inpf_path               ""
#define outpf_path              ""

/* Messaging functionality: */
#ifdef  NO_STDERR_OUTP

void m_sys_err (const char *format, ...)
{
         if ( format ) {
            /* We don't need "format". */
         }
}

void m_err (const char *format, ...)
{
        if ( format ) {
           /* We don't need "format". */
        }
}

#else /* NO_STDERR_OUTP */

void m_sys_err (const char *format, ...)
{
         va_list                 va;
         int                     o_errno;

         o_errno = errno;
         va_start (va, format);
         fprintf (stderr, "Error:\n\t");
         vfprintf (stderr, format, va);
         fprintf (stderr, "\n\tLast system error: %i %s.\n",
                          o_errno, strerror (o_errno));
         va_end (va);
}

void m_err (const char *format, ...)
{
        va_list                 va;

        va_start (va, format);
        fprintf (stderr, "Error:\n\t");
        vfprintf (stderr, format, va);
        fprintf (stderr, "\n");
        va_end (va);
}

#endif /* NO_STDERR_OUTP */

int go (void)
{
        return (0);
}

int init (void)
{
        FILE                    *inpf;

        if ( inpf_path [0] == '\0' ) {
           inpf = stdin;
        } else {
           if ( (inpf = fopen (inpf_path, "r")) == NULL ) {
                  m_sys_err ("Unable to open input (%s)", inpf_path);
                  return (-1);
           }
        }
        if ( fclose (inpf) ) {
           m_sys_err ("Unable to close input (%s)", inpf_path);
           return (-1);
        }
        return (0);
}

int shut (void)
{
        FILE                    *outpf;

        if ( outpf_path [0] == '\0' ) {
           outpf = stdout;
        } else {
                if ( (outpf = fopen (outpf_path, "w")) == NULL ) {
                   m_sys_err ("Unable to open output (%s)", outpf_path);
                   return (-1);
                }
        }
        if ( ferror (outpf) ) {
           m_sys_err ("Error writing output to %s", outpf_path);
           fclose (outpf);
           return (-1);
        }
        if ( fclose (outpf) ) {
           m_sys_err ("Unable to close output (%s)", outpf_path);
           return (-1);
        }
        return (0);
}

int main (void)
{
        if ( init () ) {
           return (1);
        }
        if ( go () ) {
           return (2);
        }
        if ( shut () ) {
           return (3);
        }
        return (0);
}


